@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE Rank2Types #-}
 
 -----------------------------------------------------------------------------
@@ -34,12 +35,18 @@ import Data.Bitraversable(Bitraversable(bitraverse))
 import Data.Foldable (Foldable(foldr))
 import Data.Functor.Alt (Alt((<!>)))
 import Data.Functor.Apply (Apply ((<.>)))
-import Data.Monoid (Monoid(mappend, mempty))
 import Data.Profunctor
-import Data.Semigroup (Semigroup((<>)))
-import Data.Traversable (Traversable(traverse))
 import Prelude hiding (foldr)
 
+#if !(MIN_VERSION_base(4,8,0))
+import Data.Monoid (Monoid(mappend, mempty))
+import Data.Traversable (Traversable(traverse))
+#endif
+
+#if !(MIN_VERSION_base(4,11,0))
+import Data.Semigroup (Semigroup((<>)))
+#endif
+
 -- | 'Validation' is 'Either' with a Left that is a 'Monoid'
 data Validation e a
   = Failure e
@@ -98,9 +105,11 @@ instance Semigroup e => Semigroup (Validation e a) where
 
 instance Monoid e => Monoid (Validation e a) where
   mempty = Failure mempty
+#if !(MIN_VERSION_base(4,11,0))
   x@Success{} `mappend` _ = x
   _ `mappend` x@Success{} = x
   Failure e1 `mappend` Failure e2 = Failure (e1 `mappend` e2)
+#endif
 
 type Prism s t a b = forall p f. (Choice p, Applicative f) => p a (f b) -> p s (f t)
 
